@@ -1,12 +1,12 @@
 #' @import ghql
-initialize_queries <- function() 
+initialize_queries <- function()
 {
     ## Initialize Client Connection
-    con <- GraphqlClient$new("https://api.thegraph.com/subgraphs/name/ianlapham/uniswapv2")
+    con <- GraphqlClient$new("https://api.thegraph.com/subgraphs/name/ianlapham/uniswap-v2-dev")
 
     ## Prepare New Query
     qry <- Query$new()
-    
+
     ##################################################################
     ## Stats of Uniswap Factory
     ##################################################################
@@ -22,7 +22,7 @@ initialize_queries <- function()
                 totalVolumeETH
                 totalLiquidityUSD
                 totalLiquidityETH
-                txCount   
+                txCount
             }
         }'
     )
@@ -47,7 +47,7 @@ initialize_queries <- function()
                 totalLiquidityETH
                 totalVolumeUSD
                 totalLiquidityUSD
-                txCount  
+                txCount
             }
         }'
     )
@@ -76,7 +76,7 @@ initialize_queries <- function()
                 derivedETH
             }
         }'
-    )    
+    )
     ##################################################################
     ##################################################################
 
@@ -105,7 +105,7 @@ initialize_queries <- function()
 
             }
         }'
-    )    
+    )
     ##################################################################
     ##################################################################
 
@@ -156,7 +156,7 @@ initialize_queries <- function()
 
             }
         }'
-    )    
+    )
     ##################################################################
     ##################################################################
 
@@ -207,7 +207,7 @@ initialize_queries <- function()
 
             }
         }'
-    )    
+    )
     ##################################################################
     ##################################################################
 
@@ -254,7 +254,7 @@ initialize_queries <- function()
                 liquidityProviderCount
             }
         }'
-    )    
+    )
     ##################################################################
     ##################################################################
 
@@ -301,7 +301,7 @@ initialize_queries <- function()
                 liquidityProviderCount
             }
         }'
-    )    
+    )
     ##################################################################
     ##################################################################
 
@@ -346,7 +346,7 @@ initialize_queries <- function()
                 }
             }
         }'
-    )    
+    )
     ##################################################################
     ##################################################################
 
@@ -385,9 +385,9 @@ initialize_queries <- function()
                 dailyVolumeToken1
                 dailyVolumeUSD
                 dailyTxns
-            }      
+            }
         }'
-    )    
+    )
     ##################################################################
     ##################################################################
 
@@ -414,9 +414,9 @@ initialize_queries <- function()
                     }
                     liquidityTokenBalance
                 }
-            }      
+            }
         }'
-    )    
+    )
     ##################################################################
     ##################################################################
 
@@ -451,9 +451,9 @@ initialize_queries <- function()
                     liquidityTokenTotalSupply
                     liquidityTokenBalance
                 }
-            }      
+            }
         }'
-    )    
+    )
     ##################################################################
     ##################################################################
 
@@ -503,9 +503,9 @@ initialize_queries <- function()
                         }
                     }
                 }
-            }      
+            }
         }'
-    )    
+    )
     ##################################################################
     ##################################################################
 
@@ -556,9 +556,9 @@ initialize_queries <- function()
                         }
                     }
                 }
-            }      
+            }
         }'
-    )    
+    )
     ##################################################################
     ##################################################################
 
@@ -608,9 +608,9 @@ initialize_queries <- function()
                         }
                     }
                 }
-            }      
+            }
         }'
-    )    
+    )
     ##################################################################
     ##################################################################
 
@@ -646,9 +646,9 @@ initialize_queries <- function()
                         }
                     }
 
-            }      
+            }
         }'
-    )    
+    )
     ##################################################################
     ##################################################################
 
@@ -692,9 +692,9 @@ initialize_queries <- function()
                         }
                     }
 
-            }      
+            }
         }'
-    )    
+    )
     ##################################################################
     ##################################################################
 
@@ -741,9 +741,9 @@ initialize_queries <- function()
                 amount1In
                 amount1Out
                 amountUSD
-            }      
+            }
         }'
-    )    
+    )
     ##################################################################
     ##################################################################
 
@@ -790,9 +790,9 @@ initialize_queries <- function()
                 amountUSD
                 feeTo
                 feeLiquidity
-            }      
+            }
         }'
-    )    
+    )
     ##################################################################
     ##################################################################
 
@@ -839,9 +839,9 @@ initialize_queries <- function()
                 amountUSD
                 feeTo
                 feeLiquidity
-            }      
+            }
         }'
-    )    
+    )
     ##################################################################
     ##################################################################
 
@@ -1161,4 +1161,4 @@ initialize_queries <- function()
     )
 
     return(list(con, qry))
-}
\ No newline at end of file
+}
